<?php
namespace Rocket54\R54L10ntest\Domain\Model;

	/***************************************************************
	 *  Copyright notice
	 *
	 *  (c) 2013 Rainer Becker <saneinsane@netcologne.de>, rocket 54
	 *
	 *  All rights reserved
	 *
	 *  This script is part of the TYPO3 project. The TYPO3 project is
	 *  free software; you can redistribute it and/or modify
	 *  it under the terms of the GNU General Public License as published by
	 *  the Free Software Foundation; either version 3 of the License, or
	 *  (at your option) any later version.
	 *
	 *  The GNU General Public License can be found at
	 *  http://www.gnu.org/copyleft/gpl.html.
	 *
	 *  This script is distributed in the hope that it will be useful,
	 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
	 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	 *  GNU General Public License for more details.
	 *
	 *  This copyright notice MUST APPEAR in all copies of the script!
	 ***************************************************************/
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Core\Utility\MathUtility;

/**
 *
 *
 * @package r54_newsevents
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class Content extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity {

	protected $data;
	/**
	 * uid
	 * @var int
	 * @validate NotEmpty
	 */
	protected $uid;
	/**
	 * pid
	 * @var int
	 * @validate NotEmpty
	 */
	protected $pid;
	/**
	 * sorting
	 * @var int
	 * @validate NotEmpty
	 */
	protected $sorting;
	/**
	 * cType
	 * @var string
	 *
	 */
	protected $cType;
	/**
	 * records
	 * @var string
	 *
	 */
	protected $records;
	/**
	 * header
	 * @var string
	 *
	 */
	protected $header;
	/**
	 * subheader
	 * @var string
	 *
	 */
	protected $subheader;
	/**
	 * headerLink
	 * @var string
	 *
	 */
	protected $headerLink;
	/**
	 * headerLayout
	 * @var int
	 *
	 */
	protected $headerLayout;
	/**
	 * imageOrientation
	 * @var int
	 *
	 */
	protected $imageOrientation;
	/**
	 * bodytext
	 * @var string
	 *
	 */
	protected $bodytext;
	/**
	 * altText
	 * @var string
	 *
	 */
	protected $altText;
	/**
	 * date
	 * @var int
	 *
	 */
	protected $date;
	/**
	 * image
	 * @var string
	 *
	 */
	protected $image;
	/**
	 * multimedia
	 * @var string
	 *
	 */
	protected $multimedia;
	/**
	 * imageLink
	 * @var string
	 *
	 */
	protected $imageLink;
	/**
	 * colPos
	 * @var int
	 *
	 */
	protected $colPos;

	/**
	 * Returns the data
	 *
	 * @return string $data
	 */
	public function getData() {
		if (!$this->data) {
			/**
			 * @var \TYPO3\CMS\Core\Database\DatabaseConnection $db
			 */
			$db = $GLOBALS['TYPO3_DB'];

			$this->data = $db->exec_SELECTgetSingleRow('*', 'tt_content', 'uid = ' . $this->getUid());
		}
		return $this->data;
	}

	/**
	 * Returns the pid
	 *
	 * @return int $pid
	 */
	public function getPid() {
		return $this->pid;
	}

	/**
	 * Returns the sorting
	 *
	 * @return int $sorting
	 */
	public function getSorting() {
		return $this->sorting;
	}

	/**
	 * Returns the content type
	 *
	 * @return string $contentType
	 */
	public function getCType() {
		return $this->cType;
	}

	/**
	 * Returns the date
	 *
	 * @return string $date
	 */
	public function getDate() {
		return $this->date;
	}

	/**
	 * Returns the header
	 *
	 * @return string $header
	 */
	public function getHeader() {
		return $this->header;
	}

	/**
	 * Returns the subheader
	 *
	 * @return string $subheader
	 */
	public function getSubheader() {
		return $this->subheader;
	}

	/**
	 * Returns the headerLink
	 *
	 * @return string $headerLink
	 */
	public function getHeaderLink() {
		return $this->headerLink;
	}

	/**
	 * Returns the headerLayout
	 *
	 * @return int $headerLayout
	 */
	public function getHeaderLayout() {
		return $this->headerLayout;
	}

	/**
	 * Returns the imageOrientation
	 *
	 * @return int $imageOrientation
	 */
	public function getImageOrientation() {
		return $this->imageOrientation;
	}

	/**
	 * Returns the bodytext
	 *
	 * @return string $bodytext
	 */
	public function getBodytext() {
		return $this->bodytext;
	}

	/**
	 * Returns the altText
	 *
	 * @return string $alttext
	 */
	public function getAltText() {
		return $this->altText;
	}

	/**
	 * Returns the image
	 *
	 * @return string $image
	 */
	public function getImage() {
		return $this->image;
	}

	/**
	 * Returns the multimedia
	 *
	 * @return string $multimedia
	 */
	public function getMultimedia() {
		return $this->multimedia;
	}

	/**
	 * Returns the imageLink
	 *
	 * @return string $imageLink
	 */
	public function getImageLink() {
		return $this->imageLink;
	}

	/**
	 * Returns the colPos
	 *
	 * @return int $colPos
	 */
	public function getColPos() {
		return $this->colPos;
	}

	public function getLocalizedUid() {
		return $this->_localizedUid;
	}

	public function getRecords() {
		return $this->records;
	}

	public function getContentRecords() {
		$result = array();
		$recordList = GeneralUtility::trimExplode(',', $this->records, TRUE);
		foreach($recordList as $record) {
			if (strpos($record,'tt_content_') === 0) {
				list($foo, $uid) = GeneralUtility::trimExplode('tt_content_', $record);
				$result[] = $uid;
			}
		}
		return $result;
	}

	public function getIsInternalHeaderLink() {
		return MathUtility::canBeInterpretedAsInteger($this->headerLink);
	}

}

?>