<?php
namespace Rocket54\R54L10ntest\Domain\Repository;

	/***************************************************************
	 *  Copyright notice
	 *
	 *  (c) 2013 Rainer Becker <saneinsane@netcologne.de>, rocket 54
	 *
	 *  All rights reserved
	 *
	 *  This script is part of the TYPO3 project. The TYPO3 project is
	 *  free software; you can redistribute it and/or modify
	 *  it under the terms of the GNU General Public License as published by
	 *  the Free Software Foundation; either version 3 of the License, or
	 *  (at your option) any later version.
	 *
	 *  The GNU General Public License can be found at
	 *  http://www.gnu.org/copyleft/gpl.html.
	 *
	 *  This script is distributed in the hope that it will be useful,
	 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
	 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	 *  GNU General Public License for more details.
	 *
	 *  This copyright notice MUST APPEAR in all copies of the script!
	 ***************************************************************/
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Persistence\Generic\Exception;
use TYPO3\CMS\Extbase\Utility\DebuggerUtility;
use TYPO3\CMS\Frontend\Page\PageRepository;

/**
 *
 *
 * @package r54_newsevents
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class ContentRepository extends \TYPO3\CMS\Extbase\Persistence\Repository {
	protected $defaultOrderings = array('sorting' => \TYPO3\CMS\Extbase\Persistence\QueryInterface::ORDER_ASCENDING);

	/**
	 * @param int $pid
	 * @param int $colPos
	 * @param int $slide
	 * @return array|\TYPO3\CMS\Extbase\Persistence\QueryResultInterface
	 */
	public function findContents($pid = NULL, $colPos = NULL, $slide = NULL){
		if (is_null($pid)) {
			if ($GLOBALS['TSFE']->page['content_from_pid']) {
				$pid = $GLOBALS['TSFE']->page['content_from_pid'];
			} else {
				$pid = $GLOBALS['TSFE']->id;
			}
		}
		$query = $this->createQuery();
		if ($pid) {
			$query->getQuerySettings()->setStoragePageIds(array($pid));
		} else {
			$query->getQuerySettings()->setRespectStoragePage(FALSE);
		}
		if (!is_null($colPos)) {
			$query->matching($query->equals('colPos', $colPos));
		}
		$contents = $query->execute();
		if (!$contents->count() && isset($slide)) {
			$contents = $this->getSlideContents($query, $pid, $slide);
		}

		$contents = $this->resolveShortCuts($contents->toArray());

		return $contents;
	}

	/**
	 * @param \array $contents
	 */
	protected function resolveShortCuts($contents){
		$resolvedContents = array();
		/**
		 * @var \Rocket54\R54Themes\Domain\Model\Content $content
		 */
		foreach($contents as $content) {
			if ($content->getCType() == 'shortcut') {
				foreach($content->getContentRecords() as $linkedRecordUid) {
					$linkedElement = $this->findByUid($linkedRecordUid);
					if ($linkedElement) {
						$resolvedContents[] = $linkedElement;
					}
				}
			} else {
				$resolvedContents[] = $content;
			}
		}
		return $resolvedContents;
	}


	/**
	 * @param \TYPO3\CMS\Extbase\Persistence\QueryInterface $query
	 * @param int $slide
	 */
	protected function getSlideContents($query, $pid, $slide){
		if ($slide != -1) {
			throw new Exception('Unknown slide param: ' . $slide);
		}

		$mountpointRange = GeneralUtility::_GP('MP') !== NULL ? GeneralUtility::_GP('MP') : '';
		$pageSelect = new PageRepository();
		$rootLine = $pageSelect->getRootLine($pid, $mountpointRange);
		array_shift($rootLine);

		/**
		 * @var \TYPO3\CMS\Extbase\Persistence\QueryResultInterface $contents
		 */
		$contents = NULL;
		for ($page = array_shift($rootLine); isset($page); $page = array_shift($rootLine)) {
			$pid = $page['uid'];
			$query->getQuerySettings()->setStoragePageIds(array($pid));
			$contents = $query->execute();
			if ($contents->count()) {
				return $contents;
			}
		}
	}

	/**
	 * findAllByUid
	 *
	 * @param \array $uidList
	 * @return
	 */
	public function findContentsByUid($uidList) {
		$result = array();
		foreach($uidList as $uid) {
			$el = $this->findByUid($uid);
			if ($el) {
				$result[] = $el;
			}
		}
		return $result;
		$query = $this->createQuery();
		return $query
			->matching($query->logicalOr($query->in('uid', $uidList), $query->in('l18n_parent', $uidList)))
			->execute();

	}
}

?>