<?php
namespace Rocket54\R54L10ntest\ViewHelpers;

/*                                                                        *
 *  Copyright notice                                                      *
 *                                                                        *
 *  (c) 2013 Rainer Becker, <rb@rocket54.de>                              *
 *  All rights reserved                                                   *
 *                                                                        *
 * This script is part of the TYPO3 project - inspiring people to share!  *
 *                                                                        *
 * TYPO3 is free software; you can redistribute it and/or modify it under *
 * the terms of the GNU General Public License version 2 as published by  *
 * the Free Software Foundation.                                          *
 *                                                                        *
 * This script is distributed in the hope that it will be useful, but     *
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHAN-    *
 * TABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General      *
 * Public License for more details.                                       *
 *
 *
 *
 * This ViewHelper ...
 *
 *
 *
 * extension,mime_type,name,title,size,creation_date,modification_date,width,height,description,alternative,link,downloadname
 *
 * = Examples =
 *
 * <code title="Render header">
 * </code>
 * <output>
 * </output>
 *
 **/

use TYPO3\CMS\Extbase\Utility\DebuggerUtility;

class GetReferencesViewHelper extends \TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper {

	/**
	 * @param string $field
	 * @param mixed $object
	 * @param string $as
	 * @param string $tableName
	 * @param boolean $first
	 * @param boolean $quiet
	 * @param \TYPO3\CMS\Extbase\DomainObject\AbstractEntity $record
	 * @return array
	 */
	public function render($field, $object = NULL, $as = NULL, $tableName = NULL, $first = FALSE, $quiet = TRUE) {
		if (!$as) {
			$as = $field;
		}

		if ($this->templateVariableContainer->exists($as) && $quiet) {
			return $this->renderChildren();
		}

		if ($tableName == 'pages') {
			$object = $GLOBALS['TSFE']->page;
		}

//		DebuggerUtility::var_dump($object, 'GetReferencesViewHelper object');
		if (is_subclass_of($object, 'TYPO3\CMS\Extbase\DomainObject\AbstractEntity')) {
			if (!$tableName) {
				$controllerName = $this->controllerContext->getRequest()->getControllerExtensionName();
				//$controllerName = get_class($this->controllerContext);
				$modelName = strtolower(end(explode('\\', get_class($object))));
				$tableName = 'tx_' . strtolower($controllerName) . '_domain_model_' . $modelName;
			}
			$uid = $object->getUid();
			$localizedUid = $object->_getProperty('_localizedUid');
			$sysLanguageUid = $object->_getProperty('_languageUid');
		} else if (is_array($object)) {
			if (!$tableName) {
				$tableName = 'tt_content';
			}
			$uid = $object['uid'];
			$localizedUid = $object['_LOCALIZED_UID'];
			$sysLanguageUid = $object['sys_language_uid'];
		} else {
			return "";
		}

		$l10nMode = $GLOBALS['TSFE']->TCAcachedExtras[$tableName]['l10n_mode'][$field];

		/* @var \TYPO3\CMS\Core\Resource\FileRepository $fileRepository */
		$fileRepository = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Core\\Resource\\FileRepository');

//		if ($uid == 15) {
//			DebuggerUtility::var_dump($object);
//			DebuggerUtility::var_dump(array(
//				'$tableName' => $tableName,
//				'$as' => $as,
//				'$field' => $field,
//				'$uid' => $uid,
//				'$localizedUid' => $localizedUid,
//				'$l10nMode' => $l10nMode
//			));
//		}

		if ($tableName == 'pages') {
			# special case page translation => no translation
			$fileObjects = $fileRepository->findByRelation($tableName, $field, $uid);
		} else if ($GLOBALS['TSFE']->sys_language_content == 0) {
			# default language => no translation

			$fileObjects = $fileRepository->findByRelation($tableName, $field, $uid);
		} else if ($sysLanguageUid == -1) {
			# record valid for all languages => no translation

			$fileObjects = $fileRepository->findByRelation($tableName, $field, $uid);
		} else {
			if ($l10nMode == 'exclude') {
				# no default language, l10n_mode 'exclude' => no translation
				$fileObjects = $fileRepository->findByRelation($tableName, $field, $uid);
			} else if ($l10nMode == 'mergeIfNotBlank') {
				# no default language, l10n_mode 'mergeIfNotBlank' => try translated first, then default
				if ($localizedUid) {
					$fileObjects = $fileRepository->findByRelation($tableName, $field, $localizedUid);
				}
				if (empty($fileObjects)) {
					$fileObjects = $fileRepository->findByRelation($tableName, $field, $uid);
				}
			} else {
				# default: get only translated
				if ($localizedUid) {
					$fileObjects = $fileRepository->findByRelation($tableName, $field, $localizedUid);
				}
			}
		}


		$files = array();

		if (is_array($fileObjects)) {
			/* @var \TYPO3\CMS\Core\Resource\FileReference $value */
			foreach ($fileObjects as $key => $value) {
				$files[$key]['alternative'] = $value->getAlternative();
				$files[$key]['description'] = $value->getDescription();
				$files[$key]['extension'] = $value->getExtension();
				$files[$key]['modificationTime'] = $value->getModificationTime();
				$files[$key]['name'] = $value->getName();
				$files[$key]['link'] = $value->getLink();
				$files[$key]['publicUrl'] = $value->getPublicUrl();
				$files[$key]['size'] = $value->getSize();
				$files[$key]['title'] = $value->getTitle();
				$readableName = substr($value->getName(), 0, -strlen($value->getExtension()) - 1);
				$readableName = str_replace('_', ' ', $readableName);
				$readableName = preg_replace('/^[\s\d]*/', '', $readableName);
				$files[$key]['titleOrName'] = $value->getTitle() ? $value->getTitle() : $readableName;
			}
		}


//		if ($uid == 15) {
//			DebuggerUtility::var_dump($files, 'GetReferencesViewHelper table: ' . $l10nMode . '/' . $tableName . '[' . $localizedUid . ']' . ' => ' . $as);
//		}

		if ($first && !empty($files)) {
			$files = $files[0];
		}

		$this->templateVariableContainer->add($as, $files);
		$output = $this->renderChildren();
		$this->templateVariableContainer->remove($as);

		//\TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($value->getPublicUrl(), '$files=');
		return $output;
	}
}